# Blockchain Data Trading Simulator (BDTsim)

![BDTsim Logo](img/bdtsim_logo_64.png) **BDTsim** is a framework for simulating blockchain based data trading protocols.

![Python Version](https://img.shields.io/pypi/pyversions/bdtsim)
[![PyPI Version](https://img.shields.io/pypi/v/bdtsim)](https://pypi.org/project/bdtsim/)
[![Pipeline Status](https://img.shields.io/gitlab/pipeline/MatthiasLohr/bdtsim)](https://gitlab.com/MatthiasLohr/bdtsim/pipelines)


## About BDTsim

BDTsim enables to run different [data trading protocols](protocols.md)
in different [blockchain environments](environments.md).

The `bdtsim` packages provides a command `bdtsim`, which offers several sub-commands
for carrying out simulations and working with the results.

Please take a look to the [Quickstart](quickstart.md) guide for information on how to start using
BDTsim.

For a list of changes in the latest release, please check the
[Changelog file](https://gitlab.com/MatthiasLohr/bdtsim/-/blob/master/CHANGELOG.md).

Read more about:

  * [Commands](commands.md)
  * [Protocols](protocols.md)
  * [Environments](environments.md)
  * [Data Providers](data_providers.md)
  * [Output Formats](output_formats.md)


## Affiliations

This project was created as a part of the research of [Matthias Lohr](https://mlohr.com/)
in cooperation with

  * [Competence Center for the Assessment of Railway Diagnostic and Monitoring Technologies (CCRDMT)](http://ccrdmt.uni-koblenz.de/), University of Koblenz-Landau, Koblenz, Germany
  * [Institute for Software Technology](https://ist.uni-koblenz.de/), University of Koblenz-Landau, Koblenz, Germany
  * [Institute for Web Science and Technologies](https://west.uni-koblenz.de/), University of Koblenz-Landau, Koblenz, Germany


## License

This project is published under the Apache License, Version 2.0.
See [LICENSE.md](https://gitlab.com/MatthiasLohr/bdtsim/-/blob/master/LICENSE.md) for more information.

Copyright &copy; by [Matthias Lohr](https://mlohr.com/) <mail@mlohr.com>

The BDTsim logo was created and provided by Zeyd Boukhers.
